==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttpRouteMatchHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property invert If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
 * @property match Method and value to match the header value sent with a request. Specify one match method.
 * @property name Name for the HTTP header in the client request that will be matched on.
 */
public data class RouteSpecHttpRouteMatchHeaderArgs(
    public val invert: Output<Boolean>? = null,
    public val match: Output<RouteSpecHttpRouteMatchHeaderMatchArgs>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs.builder()
            .invert(invert?.applyValue({ args0 -> args0 }))
            .match(match?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttpRouteMatchHeaderArgs].
 */
@PulumiTagMarker
public class RouteSpecHttpRouteMatchHeaderArgsBuilder internal constructor() {
    private var invert: Output<Boolean>? = null

    private var match: Output<RouteSpecHttpRouteMatchHeaderMatchArgs>? = null

    private var name: Output<String>? = null

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("uriqqlgfsmvhyvle")
    public suspend fun invert(`value`: Output<Boolean>) {
        this.invert = value
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("evjikuqmnsqcjgsy")
    public suspend fun match(`value`: Output<RouteSpecHttpRouteMatchHeaderMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("jatdbtdtprbekuia")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("cycwgehqosourlyt")
    public suspend fun invert(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.invert = mapped
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("swoynkgpqonbetgs")
    public suspend fun match(`value`: RouteSpecHttpRouteMatchHeaderMatchArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("kgrrryncigrfqpyf")
    public suspend
    fun match(argument: suspend RouteSpecHttpRouteMatchHeaderMatchArgsBuilder.() -> Unit) {
        val toBeMapped = RouteSpecHttpRouteMatchHeaderMatchArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("casrfggdmwijbnfo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): RouteSpecHttpRouteMatchHeaderArgs = RouteSpecHttpRouteMatchHeaderArgs(
        invert = invert,
        match = match,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttpRouteMatchHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property invert If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
 * @property match Method and value to match the header value sent with a request. Specify one match method.
 * @property name Name for the HTTP header in the client request that will be matched on.
 */
public data class RouteSpecHttpRouteMatchHeaderArgs(
    public val invert: Output<Boolean>? = null,
    public val match: Output<RouteSpecHttpRouteMatchHeaderMatchArgs>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchHeaderArgs.builder()
            .invert(invert?.applyValue({ args0 -> args0 }))
            .match(match?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttpRouteMatchHeaderArgs].
 */
@PulumiTagMarker
public class RouteSpecHttpRouteMatchHeaderArgsBuilder internal constructor() {
    private var invert: Output<Boolean>? = null

    private var match: Output<RouteSpecHttpRouteMatchHeaderMatchArgs>? = null

    private var name: Output<String>? = null

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("oytpvoenjprfvbse")
    public suspend fun invert(`value`: Output<Boolean>) {
        this.invert = value
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("ubqelmqrtvwonypx")
    public suspend fun match(`value`: Output<RouteSpecHttpRouteMatchHeaderMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("dojmbckaviphlknj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("iojyyipdqlcqtnjl")
    public suspend fun invert(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.invert = mapped
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("uobfsavkhqyftfuo")
    public suspend fun match(`value`: RouteSpecHttpRouteMatchHeaderMatchArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("dpvkvoupahupreec")
    public suspend fun match(argument: suspend RouteSpecHttpRouteMatchHeaderMatchArgsBuilder.() -> Unit) {
        val toBeMapped = RouteSpecHttpRouteMatchHeaderMatchArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("tpfndmurwdxfdgbb")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): RouteSpecHttpRouteMatchHeaderArgs = RouteSpecHttpRouteMatchHeaderArgs(
        invert = invert,
        match = match,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
